@@ -178,7 +178,7 @@ impl When {
     /// // Assert
     /// m.assert();
     /// ```
-    pub fn query_param<S: Into<String>>(mut self, name: S, value: S) -> Self {
+    pub fn query_param<SK: Into<String>, SV: Into<String>>(mut self, name: SK, value: SV) -> Self {
         update_cell(&self.expectations, |e| {
             if e.query_param.is_none() {
                 e.query_param = Some(Vec::new());
@@ -257,7 +257,11 @@ impl When {
     /// m.assert();
     /// assert_eq!(response.status(), 202);
     /// ```
-    pub fn x_www_form_urlencoded_tuple<S: Into<String>>(mut self, key: S, value: S) -> Self {
+    pub fn x_www_form_urlencoded_tuple<SK: Into<String>, SV: Into<String>>(
+        mut self,
+        key: SK,
+        value: SV,
+    ) -> Self {
         update_cell(&self.expectations, |e| {
             if e.x_www_form_urlencoded.is_none() {
                 e.x_www_form_urlencoded = Some(Vec::new());
@@ -607,7 +611,7 @@ impl When {
     ///
     /// mock.assert();
     /// ```
-    pub fn header<S: Into<String>>(mut self, name: S, value: S) -> Self {
+    pub fn header<SK: Into<String>, SV: Into<String>>(mut self, name: SK, value: SV) -> Self {
         update_cell(&self.expectations, |e| {
             if e.headers.is_none() {
                 e.headers = Some(Vec::new());
@@ -663,6 +667,9 @@ impl When {
     /// * `name` - The cookie name.
     /// * `value` - The expected cookie value.
     ///
+    /// > Note: This function is only available when the `cookies` feature is enabled.
+    /// > It is enabled by default.
+    ///
     /// # Example
     /// ```
     /// use httpmock::prelude::*;
@@ -684,7 +691,7 @@ impl When {
     ///
     /// mock.assert();
     /// ```
-    pub fn cookie<S: Into<String>>(mut self, name: S, value: S) -> Self {
+    pub fn cookie<SK: Into<String>, SV: Into<String>>(mut self, name: SK, value: SV) -> Self {
         update_cell(&self.expectations, |e| {
             if e.cookies.is_none() {
                 e.cookies = Some(Vec::new());
@@ -703,6 +710,9 @@ impl When {
     ///
     /// * `name` - The cookie name
     ///
+    /// > Note: This function is only available when the `cookies` feature is enabled.
+    /// > It is enabled by default.
+    ///
     /// # Example
     /// ```
     /// use httpmock::prelude::*;
@@ -1010,7 +1020,7 @@ impl Then {
     /// m.assert();
     /// assert_eq!(response.status(), 200);
     /// ```
-    pub fn header<S: Into<String>>(mut self, name: S, value: S) -> Self {
+    pub fn header<SK: Into<String>, SV: Into<String>>(mut self, name: SK, value: SV) -> Self {
         update_cell(&self.response_template, |r| {
             if r.headers.is_none() {
                 r.headers = Some(Vec::new());
