@@ -36,8 +36,10 @@ use crate::server::matchers::sources::{
     PathRegexSource, QueryParameterSource, StringBodyContainsSource, StringBodySource,
     StringPathSource, XWWWFormUrlencodedSource,
 };
+#[cfg(feature = "cookies")]
+use crate::server::matchers::targets::CookieTarget;
 use crate::server::matchers::targets::{
-    CookieTarget, FullRequestTarget, HeaderTarget, MethodTarget, PathTarget, QueryParameterTarget,
+    FullRequestTarget, HeaderTarget, MethodTarget, PathTarget, QueryParameterTarget,
     XWWWFormUrlEncodedBodyTarget,
 };
 use crate::server::matchers::Matcher;
@@ -144,6 +146,7 @@ impl MockServerState {
                     weight: 1,
                 }),
                 // Cookie exact
+                #[cfg(feature = "cookies")]
                 Box::new(MultiValueMatcher {
                     entity_name: "cookie",
                     key_comparator: Box::new(StringExactMatchComparator::new(true)),
@@ -157,6 +160,7 @@ impl MockServerState {
                     weight: 1,
                 }),
                 // Cookie exists
+                #[cfg(feature = "cookies")]
                 Box::new(MultiValueMatcher {
                     entity_name: "cookie",
                     key_comparator: Box::new(StringExactMatchComparator::new(true)),
